/*
** Copyright 2001 Double Precision, Inc.
** See COPYING for distribution information.
*/

#include	"courier_lib_config.h"
#include	"courier.h"
#include	"comctlfile.h"
#include	<sys/types.h>
#include	<stdlib.h>
#include	<string.h>
#include	<errno.h>

static const char rcsid[]="$Id: comsecurity.c,v 1.2 2004/10/23 15:54:02 mrsam Exp $";

const char *ctlfile_security(struct ctlfile *p)
{
	int i=ctlfile_searchfirst(p, COMCTLFILE_SECURITY);

	return (i < 0 ? "":p->lines[i]+1);
}
